@@ -38,7 +38,9 @@ __all__ = (
     "UserStatusType",
     "UserTypeType",
     "locationTypeType",
+    "FinSpaceDataServiceName",
     "ServiceName",
+    "ResourceServiceName",
     "PaginatorName",
 )
 
@@ -100,6 +102,7 @@ ListUsersPaginatorName = Literal["list_users"]
 UserStatusType = Literal["CREATING", "DISABLED", "ENABLED"]
 UserTypeType = Literal["APP_USER", "SUPER_USER"]
 locationTypeType = Literal["INGESTION", "SAGEMAKER"]
+FinSpaceDataServiceName = Literal["finspace-data"]
 ServiceName = Literal[
     "accessanalyzer",
     "account",
@@ -131,6 +134,7 @@ ServiceName = Literal[
     "backup",
     "backup-gateway",
     "batch",
+    "billingconductor",
     "braket",
     "budgets",
     "ce",
@@ -253,6 +257,7 @@ ServiceName = Literal[
     "kafka",
     "kafkaconnect",
     "kendra",
+    "keyspaces",
     "kinesis",
     "kinesis-video-archived-media",
     "kinesis-video-media",
@@ -401,6 +406,18 @@ ServiceName = Literal[
     "workspaces-web",
     "xray",
 ]
+ResourceServiceName = Literal[
+    "cloudformation",
+    "cloudwatch",
+    "dynamodb",
+    "ec2",
+    "glacier",
+    "iam",
+    "opsworks",
+    "s3",
+    "sns",
+    "sqs",
+]
 PaginatorName = Literal[
     "list_changesets", "list_data_views", "list_datasets", "list_permission_groups", "list_users"
 ]
