@@ -13,6 +13,8 @@ Usage::
         ListChangesetsPaginator,
         ListDataViewsPaginator,
         ListDatasetsPaginator,
+        ListPermissionGroupsPaginator,
+        ListUsersPaginator,
     )
 
     session = Session()
@@ -21,6 +23,8 @@ Usage::
     list_changesets_paginator: ListChangesetsPaginator = client.get_paginator("list_changesets")
     list_data_views_paginator: ListDataViewsPaginator = client.get_paginator("list_data_views")
     list_datasets_paginator: ListDatasetsPaginator = client.get_paginator("list_datasets")
+    list_permission_groups_paginator: ListPermissionGroupsPaginator = client.get_paginator("list_permission_groups")
+    list_users_paginator: ListUsersPaginator = client.get_paginator("list_users")
     ```
 """
 from typing import Generic, Iterator, TypeVar
@@ -32,10 +36,18 @@ from .type_defs import (
     ListChangesetsResponseTypeDef,
     ListDatasetsResponseTypeDef,
     ListDataViewsResponseTypeDef,
+    ListPermissionGroupsResponseTypeDef,
+    ListUsersResponseTypeDef,
     PaginatorConfigTypeDef,
 )
 
-__all__ = ("ListChangesetsPaginator", "ListDataViewsPaginator", "ListDatasetsPaginator")
+__all__ = (
+    "ListChangesetsPaginator",
+    "ListDataViewsPaginator",
+    "ListDatasetsPaginator",
+    "ListPermissionGroupsPaginator",
+    "ListUsersPaginator",
+)
 
 
 _ItemTypeDef = TypeVar("_ItemTypeDef")
@@ -91,3 +103,33 @@ class ListDatasetsPaginator(Boto3Paginator):
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/finspace-data.html#FinSpaceData.Paginator.ListDatasets.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_finspace_data/paginators.html#listdatasetspaginator)
         """
+
+
+class ListPermissionGroupsPaginator(Boto3Paginator):
+    """
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/finspace-data.html#FinSpaceData.Paginator.ListPermissionGroups)
+    [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_finspace_data/paginators.html#listpermissiongroupspaginator)
+    """
+
+    def paginate(
+        self, *, PaginationConfig: PaginatorConfigTypeDef = ...
+    ) -> _PageIterator[ListPermissionGroupsResponseTypeDef]:
+        """
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/finspace-data.html#FinSpaceData.Paginator.ListPermissionGroups.paginate)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_finspace_data/paginators.html#listpermissiongroupspaginator)
+        """
+
+
+class ListUsersPaginator(Boto3Paginator):
+    """
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/finspace-data.html#FinSpaceData.Paginator.ListUsers)
+    [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_finspace_data/paginators.html#listuserspaginator)
+    """
+
+    def paginate(
+        self, *, PaginationConfig: PaginatorConfigTypeDef = ...
+    ) -> _PageIterator[ListUsersResponseTypeDef]:
+        """
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/finspace-data.html#FinSpaceData.Paginator.ListUsers.paginate)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_finspace_data/paginators.html#listuserspaginator)
+        """
