@@ -14,6 +14,8 @@ Usage::
 import sys
 from typing import Dict, List, Mapping, Sequence
 
+from typing_extensions import NotRequired
+
 from .literals import (
     ApiAccessType,
     ApplicationPermissionType,
@@ -109,65 +111,49 @@ __all__ = (
 ChangesetErrorInfoTypeDef = TypedDict(
     "ChangesetErrorInfoTypeDef",
     {
-        "errorMessage": str,
-        "errorCategory": ErrorCategoryType,
+        "errorMessage": NotRequired[str],
+        "errorCategory": NotRequired[ErrorCategoryType],
     },
-    total=False,
 )
 
 ChangesetSummaryTypeDef = TypedDict(
     "ChangesetSummaryTypeDef",
     {
-        "changesetId": str,
-        "changesetArn": str,
-        "datasetId": str,
-        "changeType": ChangeTypeType,
-        "sourceParams": Dict[str, str],
-        "formatParams": Dict[str, str],
-        "createTime": int,
-        "status": IngestionStatusType,
-        "errorInfo": "ChangesetErrorInfoTypeDef",
-        "activeUntilTimestamp": int,
-        "activeFromTimestamp": int,
-        "updatesChangesetId": str,
-        "updatedByChangesetId": str,
+        "changesetId": NotRequired[str],
+        "changesetArn": NotRequired[str],
+        "datasetId": NotRequired[str],
+        "changeType": NotRequired[ChangeTypeType],
+        "sourceParams": NotRequired[Dict[str, str]],
+        "formatParams": NotRequired[Dict[str, str]],
+        "createTime": NotRequired[int],
+        "status": NotRequired[IngestionStatusType],
+        "errorInfo": NotRequired["ChangesetErrorInfoTypeDef"],
+        "activeUntilTimestamp": NotRequired[int],
+        "activeFromTimestamp": NotRequired[int],
+        "updatesChangesetId": NotRequired[str],
+        "updatedByChangesetId": NotRequired[str],
     },
-    total=False,
 )
 
 ColumnDefinitionTypeDef = TypedDict(
     "ColumnDefinitionTypeDef",
     {
-        "dataType": ColumnDataTypeType,
-        "columnName": str,
-        "columnDescription": str,
+        "dataType": NotRequired[ColumnDataTypeType],
+        "columnName": NotRequired[str],
+        "columnDescription": NotRequired[str],
     },
-    total=False,
 )
 
-_RequiredCreateChangesetRequestRequestTypeDef = TypedDict(
-    "_RequiredCreateChangesetRequestRequestTypeDef",
+CreateChangesetRequestRequestTypeDef = TypedDict(
+    "CreateChangesetRequestRequestTypeDef",
     {
         "datasetId": str,
         "changeType": ChangeTypeType,
         "sourceParams": Mapping[str, str],
         "formatParams": Mapping[str, str],
+        "clientToken": NotRequired[str],
     },
 )
-_OptionalCreateChangesetRequestRequestTypeDef = TypedDict(
-    "_OptionalCreateChangesetRequestRequestTypeDef",
-    {
-        "clientToken": str,
-    },
-    total=False,
-)
-
-
-class CreateChangesetRequestRequestTypeDef(
-    _RequiredCreateChangesetRequestRequestTypeDef, _OptionalCreateChangesetRequestRequestTypeDef
-):
-    pass
-
 
 CreateChangesetResponseTypeDef = TypedDict(
     "CreateChangesetResponseTypeDef",
@@ -178,31 +164,18 @@ CreateChangesetResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredCreateDataViewRequestRequestTypeDef = TypedDict(
-    "_RequiredCreateDataViewRequestRequestTypeDef",
+CreateDataViewRequestRequestTypeDef = TypedDict(
+    "CreateDataViewRequestRequestTypeDef",
     {
         "datasetId": str,
         "destinationTypeParams": "DataViewDestinationTypeParamsTypeDef",
+        "clientToken": NotRequired[str],
+        "autoUpdate": NotRequired[bool],
+        "sortColumns": NotRequired[Sequence[str]],
+        "partitionColumns": NotRequired[Sequence[str]],
+        "asOfTimestamp": NotRequired[int],
     },
 )
-_OptionalCreateDataViewRequestRequestTypeDef = TypedDict(
-    "_OptionalCreateDataViewRequestRequestTypeDef",
-    {
-        "clientToken": str,
-        "autoUpdate": bool,
-        "sortColumns": Sequence[str],
-        "partitionColumns": Sequence[str],
-        "asOfTimestamp": int,
-    },
-    total=False,
-)
-
-
-class CreateDataViewRequestRequestTypeDef(
-    _RequiredCreateDataViewRequestRequestTypeDef, _OptionalCreateDataViewRequestRequestTypeDef
-):
-    pass
-
 
 CreateDataViewResponseTypeDef = TypedDict(
     "CreateDataViewResponseTypeDef",
@@ -213,32 +186,19 @@ CreateDataViewResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredCreateDatasetRequestRequestTypeDef = TypedDict(
-    "_RequiredCreateDatasetRequestRequestTypeDef",
+CreateDatasetRequestRequestTypeDef = TypedDict(
+    "CreateDatasetRequestRequestTypeDef",
     {
         "datasetTitle": str,
         "kind": DatasetKindType,
         "permissionGroupParams": "PermissionGroupParamsTypeDef",
+        "clientToken": NotRequired[str],
+        "datasetDescription": NotRequired[str],
+        "ownerInfo": NotRequired["DatasetOwnerInfoTypeDef"],
+        "alias": NotRequired[str],
+        "schemaDefinition": NotRequired["SchemaUnionTypeDef"],
     },
 )
-_OptionalCreateDatasetRequestRequestTypeDef = TypedDict(
-    "_OptionalCreateDatasetRequestRequestTypeDef",
-    {
-        "clientToken": str,
-        "datasetDescription": str,
-        "ownerInfo": "DatasetOwnerInfoTypeDef",
-        "alias": str,
-        "schemaDefinition": "SchemaUnionTypeDef",
-    },
-    total=False,
-)
-
-
-class CreateDatasetRequestRequestTypeDef(
-    _RequiredCreateDatasetRequestRequestTypeDef, _OptionalCreateDatasetRequestRequestTypeDef
-):
-    pass
-
 
 CreateDatasetResponseTypeDef = TypedDict(
     "CreateDatasetResponseTypeDef",
@@ -248,29 +208,15 @@ CreateDatasetResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredCreatePermissionGroupRequestRequestTypeDef = TypedDict(
-    "_RequiredCreatePermissionGroupRequestRequestTypeDef",
+CreatePermissionGroupRequestRequestTypeDef = TypedDict(
+    "CreatePermissionGroupRequestRequestTypeDef",
     {
         "name": str,
         "applicationPermissions": Sequence[ApplicationPermissionType],
+        "description": NotRequired[str],
+        "clientToken": NotRequired[str],
     },
 )
-_OptionalCreatePermissionGroupRequestRequestTypeDef = TypedDict(
-    "_OptionalCreatePermissionGroupRequestRequestTypeDef",
-    {
-        "description": str,
-        "clientToken": str,
-    },
-    total=False,
-)
-
-
-class CreatePermissionGroupRequestRequestTypeDef(
-    _RequiredCreatePermissionGroupRequestRequestTypeDef,
-    _OptionalCreatePermissionGroupRequestRequestTypeDef,
-):
-    pass
-
 
 CreatePermissionGroupResponseTypeDef = TypedDict(
     "CreatePermissionGroupResponseTypeDef",
@@ -280,31 +226,18 @@ CreatePermissionGroupResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredCreateUserRequestRequestTypeDef = TypedDict(
-    "_RequiredCreateUserRequestRequestTypeDef",
+CreateUserRequestRequestTypeDef = TypedDict(
+    "CreateUserRequestRequestTypeDef",
     {
         "emailAddress": str,
         "type": UserTypeType,
+        "firstName": NotRequired[str],
+        "lastName": NotRequired[str],
+        "ApiAccess": NotRequired[ApiAccessType],
+        "apiAccessPrincipalArn": NotRequired[str],
+        "clientToken": NotRequired[str],
     },
 )
-_OptionalCreateUserRequestRequestTypeDef = TypedDict(
-    "_OptionalCreateUserRequestRequestTypeDef",
-    {
-        "firstName": str,
-        "lastName": str,
-        "ApiAccess": ApiAccessType,
-        "apiAccessPrincipalArn": str,
-        "clientToken": str,
-    },
-    total=False,
-)
-
-
-class CreateUserRequestRequestTypeDef(
-    _RequiredCreateUserRequestRequestTypeDef, _OptionalCreateUserRequestRequestTypeDef
-):
-    pass
-
 
 CreateUserResponseTypeDef = TypedDict(
     "CreateUserResponseTypeDef",
@@ -317,110 +250,79 @@ CreateUserResponseTypeDef = TypedDict(
 CredentialsTypeDef = TypedDict(
     "CredentialsTypeDef",
     {
-        "accessKeyId": str,
-        "secretAccessKey": str,
-        "sessionToken": str,
+        "accessKeyId": NotRequired[str],
+        "secretAccessKey": NotRequired[str],
+        "sessionToken": NotRequired[str],
     },
-    total=False,
 )
 
-_RequiredDataViewDestinationTypeParamsTypeDef = TypedDict(
-    "_RequiredDataViewDestinationTypeParamsTypeDef",
+DataViewDestinationTypeParamsTypeDef = TypedDict(
+    "DataViewDestinationTypeParamsTypeDef",
     {
         "destinationType": str,
+        "s3DestinationExportFileFormat": NotRequired[ExportFileFormatType],
+        "s3DestinationExportFileFormatOptions": NotRequired[Mapping[str, str]],
     },
 )
-_OptionalDataViewDestinationTypeParamsTypeDef = TypedDict(
-    "_OptionalDataViewDestinationTypeParamsTypeDef",
-    {
-        "s3DestinationExportFileFormat": ExportFileFormatType,
-        "s3DestinationExportFileFormatOptions": Mapping[str, str],
-    },
-    total=False,
-)
-
-
-class DataViewDestinationTypeParamsTypeDef(
-    _RequiredDataViewDestinationTypeParamsTypeDef, _OptionalDataViewDestinationTypeParamsTypeDef
-):
-    pass
-
 
 DataViewErrorInfoTypeDef = TypedDict(
     "DataViewErrorInfoTypeDef",
     {
-        "errorMessage": str,
-        "errorCategory": ErrorCategoryType,
+        "errorMessage": NotRequired[str],
+        "errorCategory": NotRequired[ErrorCategoryType],
     },
-    total=False,
 )
 
 DataViewSummaryTypeDef = TypedDict(
     "DataViewSummaryTypeDef",
     {
-        "dataViewId": str,
-        "dataViewArn": str,
-        "datasetId": str,
-        "asOfTimestamp": int,
-        "partitionColumns": List[str],
-        "sortColumns": List[str],
-        "status": DataViewStatusType,
-        "errorInfo": "DataViewErrorInfoTypeDef",
-        "destinationTypeProperties": "DataViewDestinationTypeParamsTypeDef",
-        "autoUpdate": bool,
-        "createTime": int,
-        "lastModifiedTime": int,
+        "dataViewId": NotRequired[str],
+        "dataViewArn": NotRequired[str],
+        "datasetId": NotRequired[str],
+        "asOfTimestamp": NotRequired[int],
+        "partitionColumns": NotRequired[List[str]],
+        "sortColumns": NotRequired[List[str]],
+        "status": NotRequired[DataViewStatusType],
+        "errorInfo": NotRequired["DataViewErrorInfoTypeDef"],
+        "destinationTypeProperties": NotRequired["DataViewDestinationTypeParamsTypeDef"],
+        "autoUpdate": NotRequired[bool],
+        "createTime": NotRequired[int],
+        "lastModifiedTime": NotRequired[int],
     },
-    total=False,
 )
 
 DatasetOwnerInfoTypeDef = TypedDict(
     "DatasetOwnerInfoTypeDef",
     {
-        "name": str,
-        "phoneNumber": str,
-        "email": str,
+        "name": NotRequired[str],
+        "phoneNumber": NotRequired[str],
+        "email": NotRequired[str],
     },
-    total=False,
 )
 
 DatasetTypeDef = TypedDict(
     "DatasetTypeDef",
     {
-        "datasetId": str,
-        "datasetArn": str,
-        "datasetTitle": str,
-        "kind": DatasetKindType,
-        "datasetDescription": str,
-        "ownerInfo": "DatasetOwnerInfoTypeDef",
-        "createTime": int,
-        "lastModifiedTime": int,
-        "schemaDefinition": "SchemaUnionTypeDef",
-        "alias": str,
+        "datasetId": NotRequired[str],
+        "datasetArn": NotRequired[str],
+        "datasetTitle": NotRequired[str],
+        "kind": NotRequired[DatasetKindType],
+        "datasetDescription": NotRequired[str],
+        "ownerInfo": NotRequired["DatasetOwnerInfoTypeDef"],
+        "createTime": NotRequired[int],
+        "lastModifiedTime": NotRequired[int],
+        "schemaDefinition": NotRequired["SchemaUnionTypeDef"],
+        "alias": NotRequired[str],
     },
-    total=False,
 )
 
-_RequiredDeleteDatasetRequestRequestTypeDef = TypedDict(
-    "_RequiredDeleteDatasetRequestRequestTypeDef",
+DeleteDatasetRequestRequestTypeDef = TypedDict(
+    "DeleteDatasetRequestRequestTypeDef",
     {
         "datasetId": str,
+        "clientToken": NotRequired[str],
     },
 )
-_OptionalDeleteDatasetRequestRequestTypeDef = TypedDict(
-    "_OptionalDeleteDatasetRequestRequestTypeDef",
-    {
-        "clientToken": str,
-    },
-    total=False,
-)
-
-
-class DeleteDatasetRequestRequestTypeDef(
-    _RequiredDeleteDatasetRequestRequestTypeDef, _OptionalDeleteDatasetRequestRequestTypeDef
-):
-    pass
-
 
 DeleteDatasetResponseTypeDef = TypedDict(
     "DeleteDatasetResponseTypeDef",
@@ -430,27 +332,13 @@ DeleteDatasetResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredDeletePermissionGroupRequestRequestTypeDef = TypedDict(
-    "_RequiredDeletePermissionGroupRequestRequestTypeDef",
+DeletePermissionGroupRequestRequestTypeDef = TypedDict(
+    "DeletePermissionGroupRequestRequestTypeDef",
     {
         "permissionGroupId": str,
+        "clientToken": NotRequired[str],
     },
 )
-_OptionalDeletePermissionGroupRequestRequestTypeDef = TypedDict(
-    "_OptionalDeletePermissionGroupRequestRequestTypeDef",
-    {
-        "clientToken": str,
-    },
-    total=False,
-)
-
-
-class DeletePermissionGroupRequestRequestTypeDef(
-    _RequiredDeletePermissionGroupRequestRequestTypeDef,
-    _OptionalDeletePermissionGroupRequestRequestTypeDef,
-):
-    pass
-
 
 DeletePermissionGroupResponseTypeDef = TypedDict(
     "DeletePermissionGroupResponseTypeDef",
@@ -460,26 +348,13 @@ DeletePermissionGroupResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredDisableUserRequestRequestTypeDef = TypedDict(
-    "_RequiredDisableUserRequestRequestTypeDef",
+DisableUserRequestRequestTypeDef = TypedDict(
+    "DisableUserRequestRequestTypeDef",
     {
         "userId": str,
+        "clientToken": NotRequired[str],
     },
 )
-_OptionalDisableUserRequestRequestTypeDef = TypedDict(
-    "_OptionalDisableUserRequestRequestTypeDef",
-    {
-        "clientToken": str,
-    },
-    total=False,
-)
-
-
-class DisableUserRequestRequestTypeDef(
-    _RequiredDisableUserRequestRequestTypeDef, _OptionalDisableUserRequestRequestTypeDef
-):
-    pass
-
 
 DisableUserResponseTypeDef = TypedDict(
     "DisableUserResponseTypeDef",
@@ -489,26 +364,13 @@ DisableUserResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredEnableUserRequestRequestTypeDef = TypedDict(
-    "_RequiredEnableUserRequestRequestTypeDef",
+EnableUserRequestRequestTypeDef = TypedDict(
+    "EnableUserRequestRequestTypeDef",
     {
         "userId": str,
+        "clientToken": NotRequired[str],
     },
 )
-_OptionalEnableUserRequestRequestTypeDef = TypedDict(
-    "_OptionalEnableUserRequestRequestTypeDef",
-    {
-        "clientToken": str,
-    },
-    total=False,
-)
-
-
-class EnableUserRequestRequestTypeDef(
-    _RequiredEnableUserRequestRequestTypeDef, _OptionalEnableUserRequestRequestTypeDef
-):
-    pass
-
 
 EnableUserResponseTypeDef = TypedDict(
     "EnableUserResponseTypeDef",
@@ -597,27 +459,13 @@ GetDatasetResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredGetProgrammaticAccessCredentialsRequestRequestTypeDef = TypedDict(
-    "_RequiredGetProgrammaticAccessCredentialsRequestRequestTypeDef",
+GetProgrammaticAccessCredentialsRequestRequestTypeDef = TypedDict(
+    "GetProgrammaticAccessCredentialsRequestRequestTypeDef",
     {
         "environmentId": str,
+        "durationInMinutes": NotRequired[int],
     },
 )
-_OptionalGetProgrammaticAccessCredentialsRequestRequestTypeDef = TypedDict(
-    "_OptionalGetProgrammaticAccessCredentialsRequestRequestTypeDef",
-    {
-        "durationInMinutes": int,
-    },
-    total=False,
-)
-
-
-class GetProgrammaticAccessCredentialsRequestRequestTypeDef(
-    _RequiredGetProgrammaticAccessCredentialsRequestRequestTypeDef,
-    _OptionalGetProgrammaticAccessCredentialsRequestRequestTypeDef,
-):
-    pass
-
 
 GetProgrammaticAccessCredentialsResponseTypeDef = TypedDict(
     "GetProgrammaticAccessCredentialsResponseTypeDef",
@@ -658,9 +506,8 @@ GetUserResponseTypeDef = TypedDict(
 GetWorkingLocationRequestRequestTypeDef = TypedDict(
     "GetWorkingLocationRequestRequestTypeDef",
     {
-        "locationType": locationTypeType,
+        "locationType": NotRequired[locationTypeType],
     },
-    total=False,
 )
 
 GetWorkingLocationResponseTypeDef = TypedDict(
@@ -673,27 +520,14 @@ GetWorkingLocationResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredListChangesetsRequestRequestTypeDef = TypedDict(
-    "_RequiredListChangesetsRequestRequestTypeDef",
+ListChangesetsRequestRequestTypeDef = TypedDict(
+    "ListChangesetsRequestRequestTypeDef",
     {
         "datasetId": str,
+        "maxResults": NotRequired[int],
+        "nextToken": NotRequired[str],
     },
 )
-_OptionalListChangesetsRequestRequestTypeDef = TypedDict(
-    "_OptionalListChangesetsRequestRequestTypeDef",
-    {
-        "maxResults": int,
-        "nextToken": str,
-    },
-    total=False,
-)
-
-
-class ListChangesetsRequestRequestTypeDef(
-    _RequiredListChangesetsRequestRequestTypeDef, _OptionalListChangesetsRequestRequestTypeDef
-):
-    pass
-
 
 ListChangesetsResponseTypeDef = TypedDict(
     "ListChangesetsResponseTypeDef",
@@ -704,27 +538,14 @@ ListChangesetsResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredListDataViewsRequestRequestTypeDef = TypedDict(
-    "_RequiredListDataViewsRequestRequestTypeDef",
+ListDataViewsRequestRequestTypeDef = TypedDict(
+    "ListDataViewsRequestRequestTypeDef",
     {
         "datasetId": str,
+        "nextToken": NotRequired[str],
+        "maxResults": NotRequired[int],
     },
 )
-_OptionalListDataViewsRequestRequestTypeDef = TypedDict(
-    "_OptionalListDataViewsRequestRequestTypeDef",
-    {
-        "nextToken": str,
-        "maxResults": int,
-    },
-    total=False,
-)
-
-
-class ListDataViewsRequestRequestTypeDef(
-    _RequiredListDataViewsRequestRequestTypeDef, _OptionalListDataViewsRequestRequestTypeDef
-):
-    pass
-
 
 ListDataViewsResponseTypeDef = TypedDict(
     "ListDataViewsResponseTypeDef",
@@ -738,10 +559,9 @@ ListDataViewsResponseTypeDef = TypedDict(
 ListDatasetsRequestRequestTypeDef = TypedDict(
     "ListDatasetsRequestRequestTypeDef",
     {
-        "nextToken": str,
-        "maxResults": int,
+        "nextToken": NotRequired[str],
+        "maxResults": NotRequired[int],
     },
-    total=False,
 )
 
 ListDatasetsResponseTypeDef = TypedDict(
@@ -753,27 +573,13 @@ ListDatasetsResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredListPermissionGroupsRequestRequestTypeDef = TypedDict(
-    "_RequiredListPermissionGroupsRequestRequestTypeDef",
+ListPermissionGroupsRequestRequestTypeDef = TypedDict(
+    "ListPermissionGroupsRequestRequestTypeDef",
     {
         "maxResults": int,
+        "nextToken": NotRequired[str],
     },
 )
-_OptionalListPermissionGroupsRequestRequestTypeDef = TypedDict(
-    "_OptionalListPermissionGroupsRequestRequestTypeDef",
-    {
-        "nextToken": str,
-    },
-    total=False,
-)
-
-
-class ListPermissionGroupsRequestRequestTypeDef(
-    _RequiredListPermissionGroupsRequestRequestTypeDef,
-    _OptionalListPermissionGroupsRequestRequestTypeDef,
-):
-    pass
-
 
 ListPermissionGroupsResponseTypeDef = TypedDict(
     "ListPermissionGroupsResponseTypeDef",
@@ -784,26 +590,13 @@ ListPermissionGroupsResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredListUsersRequestRequestTypeDef = TypedDict(
-    "_RequiredListUsersRequestRequestTypeDef",
+ListUsersRequestRequestTypeDef = TypedDict(
+    "ListUsersRequestRequestTypeDef",
     {
         "maxResults": int,
+        "nextToken": NotRequired[str],
     },
 )
-_OptionalListUsersRequestRequestTypeDef = TypedDict(
-    "_OptionalListUsersRequestRequestTypeDef",
-    {
-        "nextToken": str,
-    },
-    total=False,
-)
-
-
-class ListUsersRequestRequestTypeDef(
-    _RequiredListUsersRequestRequestTypeDef, _OptionalListUsersRequestRequestTypeDef
-):
-    pass
-
 
 ListUsersResponseTypeDef = TypedDict(
     "ListUsersResponseTypeDef",
@@ -817,55 +610,39 @@ ListUsersResponseTypeDef = TypedDict(
 PaginatorConfigTypeDef = TypedDict(
     "PaginatorConfigTypeDef",
     {
-        "MaxItems": int,
-        "PageSize": int,
-        "StartingToken": str,
+        "MaxItems": NotRequired[int],
+        "PageSize": NotRequired[int],
+        "StartingToken": NotRequired[str],
     },
-    total=False,
 )
 
 PermissionGroupParamsTypeDef = TypedDict(
     "PermissionGroupParamsTypeDef",
     {
-        "permissionGroupId": str,
-        "datasetPermissions": Sequence["ResourcePermissionTypeDef"],
+        "permissionGroupId": NotRequired[str],
+        "datasetPermissions": NotRequired[Sequence["ResourcePermissionTypeDef"]],
     },
-    total=False,
 )
 
 PermissionGroupTypeDef = TypedDict(
     "PermissionGroupTypeDef",
     {
-        "permissionGroupId": str,
-        "name": str,
-        "description": str,
-        "applicationPermissions": List[ApplicationPermissionType],
-        "createTime": int,
-        "lastModifiedTime": int,
+        "permissionGroupId": NotRequired[str],
+        "name": NotRequired[str],
+        "description": NotRequired[str],
+        "applicationPermissions": NotRequired[List[ApplicationPermissionType]],
+        "createTime": NotRequired[int],
+        "lastModifiedTime": NotRequired[int],
     },
-    total=False,
 )
 
-_RequiredResetUserPasswordRequestRequestTypeDef = TypedDict(
-    "_RequiredResetUserPasswordRequestRequestTypeDef",
+ResetUserPasswordRequestRequestTypeDef = TypedDict(
+    "ResetUserPasswordRequestRequestTypeDef",
     {
         "userId": str,
+        "clientToken": NotRequired[str],
     },
 )
-_OptionalResetUserPasswordRequestRequestTypeDef = TypedDict(
-    "_OptionalResetUserPasswordRequestRequestTypeDef",
-    {
-        "clientToken": str,
-    },
-    total=False,
-)
-
-
-class ResetUserPasswordRequestRequestTypeDef(
-    _RequiredResetUserPasswordRequestRequestTypeDef, _OptionalResetUserPasswordRequestRequestTypeDef
-):
-    pass
-
 
 ResetUserPasswordResponseTypeDef = TypedDict(
     "ResetUserPasswordResponseTypeDef",
@@ -879,9 +656,8 @@ ResetUserPasswordResponseTypeDef = TypedDict(
 ResourcePermissionTypeDef = TypedDict(
     "ResourcePermissionTypeDef",
     {
-        "permission": str,
+        "permission": NotRequired[str],
     },
-    total=False,
 )
 
 ResponseMetadataTypeDef = TypedDict(
@@ -898,43 +674,28 @@ ResponseMetadataTypeDef = TypedDict(
 SchemaDefinitionTypeDef = TypedDict(
     "SchemaDefinitionTypeDef",
     {
-        "columns": Sequence["ColumnDefinitionTypeDef"],
-        "primaryKeyColumns": Sequence[str],
+        "columns": NotRequired[Sequence["ColumnDefinitionTypeDef"]],
+        "primaryKeyColumns": NotRequired[Sequence[str]],
     },
-    total=False,
 )
 
 SchemaUnionTypeDef = TypedDict(
     "SchemaUnionTypeDef",
     {
-        "tabularSchemaConfig": "SchemaDefinitionTypeDef",
+        "tabularSchemaConfig": NotRequired["SchemaDefinitionTypeDef"],
     },
-    total=False,
 )
 
-_RequiredUpdateChangesetRequestRequestTypeDef = TypedDict(
-    "_RequiredUpdateChangesetRequestRequestTypeDef",
+UpdateChangesetRequestRequestTypeDef = TypedDict(
+    "UpdateChangesetRequestRequestTypeDef",
     {
         "datasetId": str,
         "changesetId": str,
         "sourceParams": Mapping[str, str],
         "formatParams": Mapping[str, str],
+        "clientToken": NotRequired[str],
     },
 )
-_OptionalUpdateChangesetRequestRequestTypeDef = TypedDict(
-    "_OptionalUpdateChangesetRequestRequestTypeDef",
-    {
-        "clientToken": str,
-    },
-    total=False,
-)
-
-
-class UpdateChangesetRequestRequestTypeDef(
-    _RequiredUpdateChangesetRequestRequestTypeDef, _OptionalUpdateChangesetRequestRequestTypeDef
-):
-    pass
-
 
 UpdateChangesetResponseTypeDef = TypedDict(
     "UpdateChangesetResponseTypeDef",
@@ -945,31 +706,18 @@ UpdateChangesetResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredUpdateDatasetRequestRequestTypeDef = TypedDict(
-    "_RequiredUpdateDatasetRequestRequestTypeDef",
+UpdateDatasetRequestRequestTypeDef = TypedDict(
+    "UpdateDatasetRequestRequestTypeDef",
     {
         "datasetId": str,
         "datasetTitle": str,
         "kind": DatasetKindType,
+        "clientToken": NotRequired[str],
+        "datasetDescription": NotRequired[str],
+        "alias": NotRequired[str],
+        "schemaDefinition": NotRequired["SchemaUnionTypeDef"],
     },
 )
-_OptionalUpdateDatasetRequestRequestTypeDef = TypedDict(
-    "_OptionalUpdateDatasetRequestRequestTypeDef",
-    {
-        "clientToken": str,
-        "datasetDescription": str,
-        "alias": str,
-        "schemaDefinition": "SchemaUnionTypeDef",
-    },
-    total=False,
-)
-
-
-class UpdateDatasetRequestRequestTypeDef(
-    _RequiredUpdateDatasetRequestRequestTypeDef, _OptionalUpdateDatasetRequestRequestTypeDef
-):
-    pass
-
 
 UpdateDatasetResponseTypeDef = TypedDict(
     "UpdateDatasetResponseTypeDef",
@@ -979,30 +727,16 @@ UpdateDatasetResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredUpdatePermissionGroupRequestRequestTypeDef = TypedDict(
-    "_RequiredUpdatePermissionGroupRequestRequestTypeDef",
+UpdatePermissionGroupRequestRequestTypeDef = TypedDict(
+    "UpdatePermissionGroupRequestRequestTypeDef",
     {
         "permissionGroupId": str,
+        "name": NotRequired[str],
+        "description": NotRequired[str],
+        "applicationPermissions": NotRequired[Sequence[ApplicationPermissionType]],
+        "clientToken": NotRequired[str],
     },
 )
-_OptionalUpdatePermissionGroupRequestRequestTypeDef = TypedDict(
-    "_OptionalUpdatePermissionGroupRequestRequestTypeDef",
-    {
-        "name": str,
-        "description": str,
-        "applicationPermissions": Sequence[ApplicationPermissionType],
-        "clientToken": str,
-    },
-    total=False,
-)
-
-
-class UpdatePermissionGroupRequestRequestTypeDef(
-    _RequiredUpdatePermissionGroupRequestRequestTypeDef,
-    _OptionalUpdatePermissionGroupRequestRequestTypeDef,
-):
-    pass
-
 
 UpdatePermissionGroupResponseTypeDef = TypedDict(
     "UpdatePermissionGroupResponseTypeDef",
@@ -1012,31 +746,18 @@ UpdatePermissionGroupResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredUpdateUserRequestRequestTypeDef = TypedDict(
-    "_RequiredUpdateUserRequestRequestTypeDef",
+UpdateUserRequestRequestTypeDef = TypedDict(
+    "UpdateUserRequestRequestTypeDef",
     {
         "userId": str,
+        "type": NotRequired[UserTypeType],
+        "firstName": NotRequired[str],
+        "lastName": NotRequired[str],
+        "apiAccess": NotRequired[ApiAccessType],
+        "apiAccessPrincipalArn": NotRequired[str],
+        "clientToken": NotRequired[str],
     },
 )
-_OptionalUpdateUserRequestRequestTypeDef = TypedDict(
-    "_OptionalUpdateUserRequestRequestTypeDef",
-    {
-        "type": UserTypeType,
-        "firstName": str,
-        "lastName": str,
-        "apiAccess": ApiAccessType,
-        "apiAccessPrincipalArn": str,
-        "clientToken": str,
-    },
-    total=False,
-)
-
-
-class UpdateUserRequestRequestTypeDef(
-    _RequiredUpdateUserRequestRequestTypeDef, _OptionalUpdateUserRequestRequestTypeDef
-):
-    pass
-
 
 UpdateUserResponseTypeDef = TypedDict(
     "UpdateUserResponseTypeDef",
@@ -1049,19 +770,18 @@ UpdateUserResponseTypeDef = TypedDict(
 UserTypeDef = TypedDict(
     "UserTypeDef",
     {
-        "userId": str,
-        "status": UserStatusType,
-        "firstName": str,
-        "lastName": str,
-        "emailAddress": str,
-        "type": UserTypeType,
-        "apiAccess": ApiAccessType,
-        "apiAccessPrincipalArn": str,
-        "createTime": int,
-        "lastEnabledTime": int,
-        "lastDisabledTime": int,
-        "lastModifiedTime": int,
-        "lastLoginTime": int,
+        "userId": NotRequired[str],
+        "status": NotRequired[UserStatusType],
+        "firstName": NotRequired[str],
+        "lastName": NotRequired[str],
+        "emailAddress": NotRequired[str],
+        "type": NotRequired[UserTypeType],
+        "apiAccess": NotRequired[ApiAccessType],
+        "apiAccessPrincipalArn": NotRequired[str],
+        "createTime": NotRequired[int],
+        "lastEnabledTime": NotRequired[int],
+        "lastDisabledTime": NotRequired[int],
+        "lastModifiedTime": NotRequired[int],
+        "lastLoginTime": NotRequired[int],
     },
-    total=False,
 )
